@@ -255,6 +255,13 @@ tbl_custom_summary <- function(data,
   )
 
   # assign summary type --------------------------------------------------------
+  type <-
+    case_switch(
+      missing(type) ~
+        get_theme_element("tbl_custom_summary-arg:type") %||%
+        get_theme_element("tbl_summary-arg:type", default = type),
+      .default = type
+    )
   if (!is_empty(type)) {
     # first set default types, so selectors like `all_continuous()` can be used
     # to recast the summary type, e.g. make all continuous type "continuous2"
@@ -262,13 +269,7 @@ tbl_custom_summary <- function(data,
     # process the user-passed type argument
     cards::process_formula_selectors(
       data = scope_table_body(.list2tb(default_types, "var_type"), data[include]),
-      type =
-        case_switch(
-          missing(type) ~
-            get_theme_element("tbl_custom_summary-arg:type") %||%
-            get_theme_element("tbl_summary-arg:type", default = type),
-          .default = type
-        )
+      type = type
     )
     # fill in any types not specified by user
     type <- utils::modifyList(default_types, type)
