@@ -214,6 +214,9 @@ internal_tbl_hierarchical <- function(data,
   if ("..ard_hierarchical_overall.." %in% variables) {
     cli::cli_abort("The {.arg variables} argument cannot include a column named {.val ..ard_hierarchical_overall..}.")
   }
+  if (length(variables) != length(unique(variables))) {
+    cli::cli_abort("The {.arg variables} argument cannot contain repeated variables.")
+  }
 
   # evaluate tidyselect
   cards::process_selectors(data[variables], include = {{ include }})
@@ -362,6 +365,7 @@ internal_tbl_hierarchical <- function(data,
         statistic = statistic,
         total_n = (is_empty(by) && length(include) == 1)
       )
+      attr(cards_ord, "args") <- list(by = by, variables = variables, include = include)
 
       # update structure to match results for non-ordered factor variables
       which_var <- which(names(cards_ord) == "variable")
@@ -374,10 +378,11 @@ internal_tbl_hierarchical <- function(data,
       # otherwise, bind to results for the remaining include variables
       variables <- utils::head(variables, -1)
       include <- intersect(include, variables)
+      n <- NULL
       if (is_empty(include)) {
         cards_ord[cards_ord[[which_var]] %in% by, which_h + 0:1] <-
           cards_ord[cards_ord[[which_var]] %in% by, which_var + 0:1]
-        return(cards_ord)
+        return(cards_ord |> cards::filter_ard_hierarchical(sum(n) > 0))
       } else if (!is_empty(by)) {
         cards_ord <- cards_ord |>
           dplyr::filter(.data$group1 == by[1] | .data$context == "total_n")
@@ -396,7 +401,14 @@ internal_tbl_hierarchical <- function(data,
       total_n = is_empty(by)
     )
 
-    cards::bind_ard(cards, cards_ord)
+    # bind ARDs for ordered and non-ordered variable results, merge args attribute, and re-sort
+    if (!is_empty(cards_ord)) {
+      cards <- cards::bind_ard(cards_ord, cards) |>
+        cards::sort_ard_hierarchical("alphanumeric") |>
+        cards::filter_ard_hierarchical(sum(n) > 0)
+    }
+
+    cards
   } else {
     cards::ard_stack_hierarchical_count(
       data = data,
@@ -411,6 +423,8 @@ internal_tbl_hierarchical <- function(data,
 }
 
 .add_gts_column_to_cards_hierarchical <- function(cards, variables, by) {
+  args <- attributes(cards)$args
+
   # adding the name of the column the stats will populate
   if (is_empty(by)) {
     cards$gts_column <-
@@ -430,7 +444,12 @@ internal_tbl_hierarchical <- function(data,
       dplyr::mutate(gts_column = paste0("stat_", dplyr::cur_group_id()))
   }
 
-  cards |>
+  cards <- cards |>
     dplyr::ungroup() |>
     cards::as_card()
+
+  # re-add dropped args attribute
+  attr(cards, "args") <- args
+
+  cards
 }
