@@ -35,7 +35,6 @@
 #'     - `N` Overall N
 #'
 #'   The evaluated value of `.header` is also available within `tbl_strata2(.tbl_fun)`
-#' @param .stack_group_header `r lifecycle::badge("deprecated")`
 #' @param .quiet `r lifecycle::badge("deprecated")`
 #'
 #' @section Tips:
@@ -101,7 +100,6 @@ tbl_strata <- function(data,
                        .combine_args = NULL,
                        .header =
                          ifelse(.combine_with == "tbl_merge", "**{strata}**", "{strata}"),
-                       .stack_group_header = NULL,
                        .quiet = NULL) {
   set_cli_abort_call()
 
@@ -128,7 +126,6 @@ tbl_strata <- function(data,
     .combine_with = .combine_with,
     .combine_args = .combine_args,
     .header = .header,
-    .stack_group_header = .stack_group_header,
     .parent_fun = "tbl_strata"
   )
 }
@@ -144,7 +141,6 @@ tbl_strata2 <- function(data,
                         .combine_args = NULL,
                         .header =
                           ifelse(.combine_with == "tbl_merge", "**{strata}**", "{strata}"),
-                        .stack_group_header = NULL,
                         .quiet = TRUE) {
   set_cli_abort_call()
 
@@ -171,7 +167,6 @@ tbl_strata2 <- function(data,
     .combine_with = .combine_with,
     .combine_args = .combine_args,
     .header = .header,
-    .stack_group_header = .stack_group_header,
     .parent_fun = "tbl_strata2"
   )
 }
@@ -184,7 +179,6 @@ tbl_strata_internal <- function(data,
                                 .combine_with = c("tbl_merge", "tbl_stack"),
                                 .combine_args = NULL,
                                 .header = NULL,
-                                .stack_group_header = NULL,
                                 .parent_fun) {
   check_string(.header)
 
@@ -245,21 +239,6 @@ tbl_strata_internal <- function(data,
         )
     )
 
-  # deprecated argument --------------------------------------------------------
-  if (!is.null(.stack_group_header) && isTRUE(.combine_with == "tbl_stack")) {
-    lifecycle::deprecate_stop(
-      when = "1.5.1",
-      what = "gtsummary::tbl_strata(.stack_group_header)",
-      details =
-        switch(isFALSE(.stack_group_header),
-               glue(
-                 "Use the following instead:\n",
-                 "gtsummary::tbl_strata(.combine_args = list(group_header = NULL))"
-               )
-        )
-    )
-  }
-
   # combining tbls -------------------------------------------------------------
   .combine_args <-
     # default arguments
