@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("cardx", "survey"), reference_pkg = "gtsummary") && is_pkg_installed("broom", reference_pkg = "cardx"))
+skip_if_not(is_pkg_installed(c("cardx", "survey", "withr")) && is_pkg_installed("broom", ref = "cardx"))
 svy_trial <- survey::svydesign(~1, data = trial, weights = ~1)
 
 test_that("add_ci(method) with no `by`", {
@@ -723,7 +723,7 @@ test_that("add_ci() correctly handles dichotomous variables", {
 
   expect_equal(
     tbl$inputs$value |> lapply(as.character),
-    tbl$cards$add_ci[c("variable", "variable_level")] |> unique() |> deframe()
+    tbl$cards$add_ci[c("variable", "variable_level")] |> unique() |> deframe() |> lapply(as.character)
   )
 })
 
@@ -740,3 +740,61 @@ test_that("add_ci() messaging for tbl_svysummary(percent)", {
     "function is meant to work with"
   )
 })
+
+test_that("add_ci.tbl_svysummary() ordering for factors", {
+  withr::local_seed(123)
+
+  # generate sample data
+  expect_error(
+    df <-
+      dplyr::tibble(factor = sample(c("A", "B", "C", NA), 100, replace = TRUE)) |>
+      dplyr::mutate(
+        factor2 = factor(factor, levels = c("C", "B", "A")),
+        factor = factor(factor),
+      ) |>
+      survey::svydesign(ids = ~ 1, data = _, weights = ~1) |>
+      tbl_svysummary(missing = "no") |>
+      add_ci() |>
+      modify_column_unhide(variable) |>
+      remove_row_type() |>
+      as.data.frame(col_label = FALSE),
+    NA
+  )
+
+  expect_equal(
+    df |>
+      dplyr::filter(variable == "factor") |>
+      dplyr::arrange(label) |>
+      dplyr::select(label, stat_0, ci_stat_0),
+    df |>
+      dplyr::filter(variable == "factor2") |>
+      dplyr::arrange(label) |>
+      dplyr::select(label, stat_0, ci_stat_0)
+  )
+
+
+  # check for issue #2052
+  data(api, package = "survey")
+  dclus1 <-
+    survey::svydesign(
+      id = ~dnum,
+      weights = ~pw,
+      data = apiclus1 |> dplyr::mutate(both2 = factor(both, levels = c("Yes", "No"))),
+      fpc = ~fpc
+    )
+
+  # checks the order of the CI columns matches the primary column
+  expect_equal(
+    dclus1 |>
+      tbl_svysummary(by = "both", include = stype) |>
+      add_ci() |>
+      as.data.frame(col_labels = FALSE) |>
+      dplyr::pull(ci_stat_1),
+    dclus1 |>
+      tbl_svysummary(by = "both2", include = stype) |>
+      add_ci() |>
+      as.data.frame(col_labels = FALSE) |>
+      dplyr::pull(ci_stat_2)
+  )
+})
+
