@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("survey", reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed("survey"))
 
 svy_mtcars <- survey::svydesign(~1, data = mtcars, weights = ~1)
 
