@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("survey", reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed("survey"))
 
 svy_titanic <- survey::svydesign(~1, data = as.data.frame(Titanic), weights = ~Freq)
 df_titanic <- as.data.frame(Titanic) |> tidyr::uncount(weights = Freq)
@@ -78,7 +78,7 @@ test_that("tbl_svysummary(statistic)", {
       ) |>
       as.data.frame(col_labels = FALSE) |>
       dplyr::pull(stat_0),
-    "n=61 | N=193 | p=32 | N_obs=200 | N_miss=7 | N_nonmiss=193 | p_miss=3.5 | p_nonmiss=97 | p.std.error=0.0 | deff=Inf | n_unweighted=61 | N_unweighted=193 | p_unweighted=31.6"
+    "n=61 | N=193 | p=32 | N_obs=200 | N_miss=7 | N_nonmiss=193 | p_miss=3.5 | p_nonmiss=97 | p.std.error=0.034 | deff=Inf | n_unweighted=61 | N_unweighted=193 | p_unweighted=32"
   )
 
   # continuous summary when there is no "continuous" stats (just missingness stats)
@@ -588,3 +588,15 @@ test_that("tbl_svysummary(percent)", {
     tbl_svysummary(svy_trial, by = trt, include = grade, percent = letters, statistic = ~"{p}%")
   )
 })
+
+# Fix for default formatting function issue reported in #2078
+test_that("tbl_svysummary() default fmt fn", {
+  expect_equal(
+    svy_trial |>
+      tbl_svysummary(include = age, missing_stat = "{N_miss_unweighted} ({p_miss_unweighted}%)") |>
+      as.data.frame(col_label = FALSE) |>
+      dplyr::pull(stat_0) |>
+      getElement(2L),
+    "11 (5.5%)"
+  )
+})
